bl_info = {
    "name": "Nonsense tools",
    "location": "View3D > Add > Mesh > Nonsense",
    "description": "More nonsense",
    "category": "Mesh"}

import bpy
from mathutils import Vector



def select_mirror_alt(cutoff):
        
    obj = bpy.context.scene.objects.active
    mesh = bpy.data.objects[obj.name].data.name
    verts = bpy.data.meshes[mesh].vertices

    Lside = []
    Rside = []
    coordsdict = {tuple(vert.co): vert.index for vert in verts}

    selvertsR = []
    selvertsL = []
    #update the object from edit mode
    mode = obj.mode
    bpy.ops.object.mode_set(mode='OBJECT')
    bpy.ops.object.mode_set(mode= mode) 

    #store the selected verts as a list
    for vert2 in verts:
        if vert2.select:
            if vert2.co[0] > 0:
                selvertsL.append(vert2.co)
            elif vert2.co[0] < 0:
                selvertsR.append(vert2.co)


            
    for vert in verts:
        if vert.co[0] > 0:
            Lside.append(vert.co)
        elif vert.co[0] < 0:
            Rside.append(vert.co)

    mode = obj.mode
    bpy.ops.object.mode_set(mode='OBJECT')

    for vertco in selvertsL:
        for vertcoR in Rside:
            delta = 0
            newcoR = vertcoR.copy()
            newcoR[0] *= -1
            delta = (newcoR - vertco).length
            newcoR[0] *= -1
            if delta == 0:
                verts[coordsdict[tuple(vertcoR)]].select = True
            elif 0 < delta < cutoff or 0 > delta > -cutoff:
                verts[coordsdict[tuple(vertcoR)]].select = True
                

    for vertco2 in selvertsR:
        for vertcoL in Lside:
            delta = 0
            newcoL = vertcoL.copy()
            newcoL[0] *= -1
            delta = (newcoL - vertco2).length
            newcoL[0] *= -1
            if delta == 0:
                verts[coordsdict[tuple(vertcoL)]].select = True
            elif 0 < delta < cutoff or 0 > delta > -cutoff:
                verts[coordsdict[tuple(vertcoL)]].select = True

                
    bpy.ops.object.mode_set(mode=mode) 


class select_mirror_alt_op(bpy.types.Operator):
    """Mirror selection with a falloff"""
    bl_idname = "mesh.mirror_sel_alt"
    bl_label = "Mirror select with falloff"
    bl_space_type = 'VIEW_3D'
    bl_region_type = 'TOOLS'
    bl_category = "Tools"
    bl_options = {'UNDO', 'REGISTER'}
    
    falloff = bpy.props.FloatProperty(default = 0.0001)
    
    
    
    def execute(self, context):
       select_mirror_alt(self.falloff)

       return {'FINISHED'}



class NonsenseToolsPanel(bpy.types.Panel):
    """Creates a Panel in the 3D View"""
    bl_label = "Nonsense mesh tools"    
    bl_space_type = 'VIEW_3D'
    bl_region_type = 'TOOLS'
    bl_category = "Tools"

    def draw(self, context):
        layout = self.layout

        obj = context.object

        row = layout.row()
        row.operator("mesh.mirror_sel_alt")



def register():
    bpy.utils.register_class(select_mirror_alt_op)
    bpy.utils.register_class(NonsenseToolsPanel)

def unregister():
    bpy.utils.unregister_class(select_mirror_alt_op)
    bpy.utils.unregister_class(NonsenseToolsPanel)
    
if __name__ == "__main__":
    register()
